@@ -27,7 +27,6 @@
 #include "platform.h"
 #include "gnunet_util_lib.h"
 #include "gnunet_dns_service.h"
-#include "gnunet_dnsparser_lib.h"
 
 /**
  * Handle to transport service.
@@ -203,7 +202,7 @@ display_record (const struct GNUNET_DNSPARSER_Record *record)
     else
     {
       GNUNET_asprintf (&tmp,
-                       "priority %u, weight = %s, port = %u, target = %s",
+                       "priority %u, weight = %u, port = %u, target = %s",
                        (unsigned int) record->data.srv->priority,
                        (unsigned int) record->data.srv->weight,
                        (unsigned int) record->data.srv->port,
@@ -216,7 +215,7 @@ display_record (const struct GNUNET_DNSPARSER_Record *record)
     GNUNET_asprintf (&tmp,
                      "%.*s",
                      (unsigned int) record->data.raw.data_len,
-                     record->data.raw.data);
+                     (char*) record->data.raw.data);
     format = tmp;
     break;
 
