@@ -28,9 +28,8 @@
 
 #include "platform.h"
 #include "gnunet_configuration_lib.h"
-#include "gnunet_crypto_lib.h"
+#include "gnunet_util_lib.h"
 #include "gnunet_scheduler_lib.h"
-#include "gnunet_strings_lib.h"
 #include "gnunet_time_lib.h"
 
 enum GNUNET_MESSENGER_OperationType
