@@ -175,6 +175,7 @@ GNUNET_REVOCATION_query (const struct GNUNET_CONFIGURATION_Handle *cfg,
   };
   struct QueryMessage *qm;
   struct GNUNET_MQ_Envelope *env;
+  size_t key_len;
 
   q->mq = GNUNET_CLIENT_connect (cfg,
                                  "revocation",
@@ -188,10 +189,11 @@ GNUNET_REVOCATION_query (const struct GNUNET_CONFIGURATION_Handle *cfg,
   }
   q->func = func;
   q->func_cls = func_cls;
-  env = GNUNET_MQ_msg (qm,
-                       GNUNET_MESSAGE_TYPE_REVOCATION_QUERY);
-  qm->reserved = htonl (0);
-  qm->key = *key;
+  key_len = GNUNET_IDENTITY_public_key_get_length (key);
+  env = GNUNET_MQ_msg_extra (qm, key_len,
+                             GNUNET_MESSAGE_TYPE_REVOCATION_QUERY);
+  GNUNET_IDENTITY_write_public_key_to_buffer (key, &qm[1], key_len);
+  qm->key_len = htonl (key_len);
   GNUNET_MQ_send (q->mq,
                   env);
   return q;
@@ -407,14 +409,14 @@ REV_create_signature_message (const struct GNUNET_REVOCATION_PowP *pow)
   size_t ksize;
 
   pk = (const struct GNUNET_IDENTITY_PublicKey *) &pow[1];
-  ksize = GNUNET_IDENTITY_key_get_length (pk);
+  ksize = GNUNET_IDENTITY_public_key_get_length (pk);
   spurp = GNUNET_malloc (sizeof (*spurp) + ksize);
   spurp->timestamp = pow->timestamp;
   spurp->purpose.purpose = htonl (GNUNET_SIGNATURE_PURPOSE_REVOCATION);
   spurp->purpose.size = htonl (sizeof(*spurp) + ksize);
-  GNUNET_IDENTITY_write_key_to_buffer (pk,
-                                       (char*) &spurp[1],
-                                       ksize);
+  GNUNET_IDENTITY_write_public_key_to_buffer (pk,
+                                              (char*) &spurp[1],
+                                              ksize);
   return spurp;
 }
 
@@ -426,14 +428,15 @@ check_signature_identity (const struct GNUNET_REVOCATION_PowP *pow,
   unsigned char *sig;
   size_t ksize;
 
-  ksize = GNUNET_IDENTITY_key_get_length (key);
+  ksize = GNUNET_IDENTITY_public_key_get_length (key);
   spurp = REV_create_signature_message (pow);
   sig = ((unsigned char*) &pow[1] + ksize);
   if (GNUNET_OK !=
-      GNUNET_IDENTITY_signature_verify_raw_ (GNUNET_SIGNATURE_PURPOSE_REVOCATION,
-                                             &spurp->purpose,
-                                             sig,
-                                             key))
+      GNUNET_IDENTITY_signature_verify_raw_ (
+        GNUNET_SIGNATURE_PURPOSE_REVOCATION,
+        &spurp->purpose,
+        sig,
+        key))
   {
     return GNUNET_SYSERR;
   }
@@ -503,7 +506,7 @@ GNUNET_REVOCATION_check_pow (const struct GNUNET_REVOCATION_PowP *pow,
   GNUNET_memcpy (&buf[sizeof(uint64_t)],
                  &pow->timestamp,
                  sizeof (uint64_t));
-  pklen = GNUNET_IDENTITY_key_get_length (pk);
+  pklen = GNUNET_IDENTITY_public_key_get_length (pk);
   if (0 > pklen)
   {
     GNUNET_break (0);
@@ -578,7 +581,7 @@ sign_pow_identity (const struct GNUNET_IDENTITY_PrivateKey *key,
   ts = GNUNET_TIME_absolute_subtract (ts,
                                       GNUNET_TIME_UNIT_WEEKS);
   pk = (const struct GNUNET_IDENTITY_PublicKey *) &pow[1];
-  ksize = GNUNET_IDENTITY_key_get_length (pk);
+  ksize = GNUNET_IDENTITY_public_key_get_length (pk);
   pow->timestamp = GNUNET_TIME_absolute_hton (ts);
   rp = REV_create_signature_message (pow);
   sig = ((char*) &pow[1]) + ksize;
@@ -691,7 +694,7 @@ GNUNET_REVOCATION_pow_round (struct GNUNET_REVOCATION_PowCalculationHandle *pc)
   GNUNET_memcpy (&buf[sizeof(uint64_t)],
                  &pc->pow->timestamp,
                  sizeof (uint64_t));
-  ksize = GNUNET_IDENTITY_key_get_length (pk);
+  ksize = GNUNET_IDENTITY_public_key_get_length (pk);
   GNUNET_assert (0 < ksize);
   GNUNET_memcpy (&buf[sizeof(uint64_t) * 2],
                  pk,
@@ -749,7 +752,7 @@ GNUNET_REVOCATION_proof_get_size (const struct GNUNET_REVOCATION_PowP *pow)
 
   size = sizeof (struct GNUNET_REVOCATION_PowP);
   pk = (const struct GNUNET_IDENTITY_PublicKey *) &pow[1];
-  ksize = GNUNET_IDENTITY_key_get_length (pk);
+  ksize = GNUNET_IDENTITY_public_key_get_length (pk);
   size += ksize;
   size += GNUNET_IDENTITY_signature_get_raw_length_by_type (pk->type);
   return size;
