@@ -24,11 +24,11 @@
  * @author Christian Grothoff
  * @author Florian Dold
  */
+
 #include "platform.h"
 #include <gcrypt.h>
 #include <sodium.h>
-#include "gnunet_crypto_lib.h"
-#include "gnunet_strings_lib.h"
+#include "gnunet_util_lib.h"
 #include "benchmark.h"
 
 #define EXTRA_CHECKS 0
